@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -185,7 +185,7 @@ sub draw {
             );
         }
         else {
-            my $temp = $self->fretboard->{$string}[$self->position + $note - 1];
+            my $temp = $self->fretboard->{$string}[ ($self->position + $note - 1) % @{ $self->fretboard->{1} } ];
             push @chord, $temp;
             print "Dot at $note,$string = $temp\n" if $self->verbose;
 
@@ -233,7 +233,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0100
+version 0.0200
 
 =head1 SYNOPSIS
 
